@@ -32,7 +32,9 @@ class Backend:
         self._create_protocols = create_protocols
 
     def id(self, pv_proxy):
-        return pv_proxy.GetGlobalIDAsString()
+        if pv_proxy:
+            return pv_proxy.GetGlobalIDAsString()
+        return ""
 
     def object(self, pv_id):
         try:
@@ -46,6 +48,7 @@ class Backend:
         )
 
     def mesh(self, proxy, field_to_keep=None, point_arrays=None, cell_arrays=None):
+        proxy.UpdatePipeline()
         source = proxy.GetClientSideObject()
         dataset = source.GetOutput()
         return mesh(
@@ -117,6 +120,7 @@ class Backend:
             ParaViewWebLocalRendering,
         )
         from paraview.modules.vtkPVClientWeb import vtkPVWebApplication
+        from ..vtk.addon_serializer import registerAddOnSerializers
 
         # Initialize vtk application helper
         protocol_app = vtkPVWebApplication()
@@ -133,6 +137,9 @@ class Backend:
         # Remote rendering - geometry delivery
         self._protocol.registerLinkProtocol(ParaViewWebLocalRendering())
 
+        # Add custom serializer ahead of proper vtk integration
+        registerAddOnSerializers()
+
         # Register custom protocols
         if self._create_protocols:
             protocols = self._create_protocols()
