@@ -2,6 +2,7 @@ import os
 import sys
 import shutil
 import json
+import asyncio
 
 from pywebvue.utils import abs_path
 
@@ -11,8 +12,6 @@ from wslink import register as exportRpc
 from wslink.websocket import ServerProtocol
 from wslink.websocket import LinkProtocol
 
-from twisted.internet import reactor
-
 # Only used for debug
 import json
 
@@ -195,6 +194,9 @@ class CoreServer(ServerProtocol):
         self.rpcMethods = {}
         self.app = CoreServer.app
         self.app._backend.configure_protocol(self)
+        for protocol in self.app._protocols_to_register:
+            self.registerLinkProtocol(protocol)
+
         self.updateSecret(CoreServer.authentication_token)
 
         if self.app.on_ready:
@@ -257,9 +259,12 @@ class CoreServer(ServerProtocol):
     # ---------------------------------------------------------------
 
     @exportRpc("ws.vue.trigger")
-    def trigger(self, name, args, kwargs):
+    async def trigger(self, name, args, kwargs):
         with self.app.capture_changes():
-            self.app._triggers[name](*args, **kwargs)
+            if name in self.app._triggers:
+                await asyncio.coroutine(self.app._triggers[name])(*args, **kwargs)
+            else:
+                print(f"Tigger {name} seems to be missing")
 
     # ---------------------------------------------------------------
 
